aboutsummaryrefslogtreecommitdiffstats
path: root/src/common.h
diff options
context:
space:
mode:
authorMattias Andrée <m@maandree.se>2025-03-23 15:08:45 +0100
committerMattias Andrée <m@maandree.se>2025-03-23 15:08:45 +0100
commit1ea4a4d1968b767912e70e18be8f0e1e22bf9c6f (patch)
treefdb5e2eb1fb03aa672281130ef71c579a262e81a /src/common.h
parentUpdate documentation reflect that the drm method now supports CRTC list (diff)
downloadredshift-ng-1ea4a4d1968b767912e70e18be8f0e1e22bf9c6f.tar.gz
redshift-ng-1ea4a4d1968b767912e70e18be8f0e1e22bf9c6f.tar.bz2
redshift-ng-1ea4a4d1968b767912e70e18be8f0e1e22bf9c6f.tar.xz
Use libgamma to determine available adjustment method configuration options
Signed-off-by: Mattias Andrée <m@maandree.se>
Diffstat (limited to 'src/common.h')
-rw-r--r--src/common.h24
1 files changed, 22 insertions, 2 deletions
diff --git a/src/common.h b/src/common.h
index aa929ae..578a82d 100644
--- a/src/common.h
+++ b/src/common.h
@@ -1184,14 +1184,34 @@ extern int verbose;
/**
* Create an initialised state object for direct gamma adjustments
*
* @param state_out Output parameter for the state object
* @return 0 on success, -1 on failure
*
* `*state_out` is set (potentially to `NULL`) on failure
*/
int direct_create(GAMMA_STATE **state_out, int method, const char *method_name);
/**
+ * Print help on options for the adjustment method using direct gamma adjustments
+ *
+ * @param f Output sink
+ * @param method libgamma constant for the adjustment method
+ */
+void direct_print_help(FILE *f, int method);
+
+/**
+ * Configure the adjustment method using direct gamma adjustments
+ *
+ * @param state State object for the adjustment method
+ * @param key Option to configure
+ * @param value Option value to set
+ * @return 0 on success, -1 on failure
+ */
+int direct_set_option(GAMMA_STATE *state, const char *key, const char *value);
+
+/**
* Select partitions to apply adjustments to using direct gamma adjustments
*
* @param state State object for the adjustment method
@@ -1184,14 +1184,34 @@ extern int verbose;
* Create an initialised state object for direct gamma adjustments
*
- * @param state_out Output parameter for the state object
- * @return 0 on success, -1 on failure
+ * @param state_out Output parameter for the state object
+ * @param method libgamma constant for the adjustment method
+ * @param method_name redshift's name for the adjustment method
+ * @return 0 on success, -1 on failure
*
* `*state_out` is set (potentially to `NULL`) on failure